import { Component } from 'vue-property-decorator';
import { AppServiceBase, Util } from "ibiz-core";
import { AppLoadingService, AppNavHistory } from "../../../../app-service";
import { AppStyle2DefaultLayout } from "../app-style2-default-layout/app-style2-default-layout";
import { IPSAppMenu } from '@ibiz/dynamic-model-api';

@Component({})
export class AppStyle2IndexViewLayout extends AppStyle2DefaultLayout {

    /**
     * 应用loading服务
     *
     * @memberof AppLayout
     */
     public appLoadingService = AppLoadingService.getInstance();
     
    /**
     * 菜单实例
     * 
     * @memberof AppStyle2IndexViewLayout
     */
    public menuInstance!: IPSAppMenu;

    /**
     * 抽屉状态
     *
     * @type {boolean}
     * @memberof AppStyle2IndexViewLayout
     */
    public contextMenuDragVisiable: boolean = false;

    /**
     * 导航服务
     * 
     * @memberof TabPageExpStyle2
     */
    protected navHistory: AppNavHistory = AppServiceBase.getInstance().getAppNavDataService();

    /**
     * 是否显示标题栏
     *
     * @readonly
     * @memberof AppDefaultViewLayout
     */
     get showCaption(){
      if(this.viewInstance && this.$parent && Util.isExist(this.viewInstance.showCaptionBar)){
          return this.viewInstance.showCaptionBar && !(this.$parent as any).noViewCaption
      }else{
          return true;
      }
    }

    /**
     * 路由列表
     * 
     * @memberof AppStyle2IndexViewLayout 
     */
    get routerList() {
        if(this.navHistory?.historyList?.length > 0){
            let temp: any = [];
            this.navHistory?.historyList.forEach((item: any)=>{
                temp.push(item.to.fullPath);
            })
            return temp;
        }else{
            return [];
        }
    }

    /**
     * 当前主题
     *
     * @memberof AppStyle2IndexViewLayout
     */
    public selectTheme() {
        let _this: any = this;
        if (_this.$router.app.$store.state.selectTheme) {
            return _this.$router.app.$store.state.selectTheme;
        } else if (localStorage.getItem('theme-class')) {
            return localStorage.getItem('theme-class');
        } else {
            return 'app-theme-studio-dark';
        }
    }

    /**
     * 路由键值
     * 
     * @memberof AppStyle2IndexViewLayout 
     */
    get routerViewKey() {
        let _this: any = this;
        return _this.$route.fullPath;
    }

    /**
     * 初始化
     * 
     * @memberof AppStyle2IndexViewLayout
     */
    public created() {
        document.getElementsByTagName('html')[0].className = this.selectTheme();
        this.$uiState.changeLayoutState({
            styleMode: 'DEFAULT'
        });
    }

    /**
     * 初始化完毕
     * 
     * @memberof AppStyle2IndexViewLayout
     */
    public mounted() {
        setTimeout(() => {
            const el = document.getElementById('app-loading-x');
            if (el) {
                el.style.display = 'none';
            }
        }, 300);
    }

    /**
     * 绘制内容
     * 
     * @memberof AppStyle2IndexViewLayout
     */
    public render(h: any): any {
        const { viewClassNames } = this.renderOptions;
        if (this.viewInstance && this.viewInstance.mainMenuAlign && Object.is(this.viewInstance.mainMenuAlign, "CENTER")) {
            const { codeName } = this.viewInstance;
            return (<studio-view
                viewName={codeName?.toLowerCase()}
                viewTitle={this.model.srfCaption}
                viewInstance={this.viewInstance}
                viewparams={this.viewparams}
                context={this.context}
                class={viewClassNames}>
                {this.$slots.default}
            </studio-view>)
        } else {
            const styleMode: any = this.$uiState.layoutState.styleMode;
            let leftContent: any;
            switch (styleMode) {
                case 'DEFAULT':
                    leftContent = this.$slots.leftExp;
                    break;
                case 'STYLE2':
                    leftContent = this.$slots.leftNavMenu;
            }
            return (
                <app-style2-layout ref="appLayout" class={viewClassNames}>
                    <template slot="header">
                        <app-style2-header>
                            <template slot="left">
                                <div class="app-style2-header__left__caption">
                                    {true ? <span class="caption__icon" on-click={() => this.contextMenuDragVisiable = !this.contextMenuDragVisiable}><icon type="md-menu" />&nbsp;</span> : null}
                                    {this.showCaption ? this.model.srfCaption : null}
                                </div>
                            </template>
                            <template slot="right">
                                {this.$slots.headerMenus}
                                {this.$topRenderService.rightItemsRenders.map((fun: any) => fun(h))}
                                <app-lang title={this.model.srfTitle || this.model.srfCaption}></app-lang>
                                {<app-orgsector />}
                                {<app-user viewStyle={this.viewInstance.viewStyle} />}
                            </template>
                        </app-style2-header>
                        {this.$slots.default}
                        {true ? <context-menu-drag viewStyle={this.viewInstance.viewStyle} contextMenuDragVisiable={this.contextMenuDragVisiable}></context-menu-drag> : null}
                    </template>
                    <app-style2-content>
                        {leftContent ?
                            <template slot="left">
                                {leftContent}
                            </template> : null}
                        {styleMode === 'DEFAULT' ? this.$slots.tabPageExp : null}
                        <div class="app-style2-content__body" on-click={() => this.contextMenuDragVisiable = false}>
                            <app-keep-alive routerList={this.routerList}>
                                <router-view key={this.routerViewKey}></router-view>
                            </app-keep-alive>
                        </div>
                        {this.$slots.bottomExp ?
                            <template slot="bottom">
                                {this.$slots.bottomExp}
                            </template> : null}
                    </app-style2-content>
                    <template slot="footer">
                        { this.viewInstance.defaultPage 
                            ? <app-style2-footer v-notification-signal={this.appLoadingService.isLoading} ref="footer" />
                            : <app-style2-footer ref="footer" />
                        }
                    </template>
                </app-style2-layout>
            );
        }

    }
}